package de.intevation.aft;

import java.io.File;

import java.sql.SQLException;

import org.w3c.dom.Document;

import de.intevation.utils.XML;

import de.intevation.db.ConnectionBuilder;

public class Sync
{
    public static final String FLYS = "flys";
    public static final String AFT  = "aft";

    public static final String CONFIG_FILE =
        System.getProperty("config.file", "config.xml");

    public static void main(String [] args) {

        File configFile = new File(CONFIG_FILE);

        if (!configFile.isFile() || !configFile.canRead()) {
            System.err.println("cannot read config file");
            System.exit(1);
        }

        Document config = XML.parseDocument(configFile, Boolean.FALSE);

        if (config == null) {
            System.err.println("cannot load config");
            System.exit(1);
        }

        ConnectionBuilder aftConnectionBuilder =
            new ConnectionBuilder(AFT, config);

        ConnectionBuilder flysConnectionBuilder =
            new ConnectionBuilder(FLYS, config);

        Rivers rivers = new Rivers(
            aftConnectionBuilder,
            flysConnectionBuilder);

        try {
            rivers.sync();
        }
        catch (SQLException sqle) {
            System.err.println("syncing failed: " + sqle.getMessage());
        }
        finally {
            rivers.close();
        }
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
